export type NotificationID = number;
export type NotificationContents = string | HTMLElement;
export type ActiveNotifications = Map<NotificationID, Notification>;
export interface NotificationOptions {
    element?: HTMLElement;
    dismissible?: boolean;
    autoDismissTimeout?: number;
    animated?: boolean;
    exitAnimationTime?: number;
}
export interface Notification {
    dismiss: () => void;
    id: NotificationID;
    timeoutID?: ReturnType<typeof window.setTimeout> | any;
    contents: NotificationContents;
    element: HTMLElement;
    animated: boolean;
}
export interface NotificationManagerOptions {
    container?: HTMLElement | null;
    defaultAutoDismissTimeout?: number;
    defaultDismissible?: boolean;
    defaultAnimated?: boolean;
    defaultExitAnimationTime?: number;
    documentInstance?: Document | {
        createElement: (tagName: string) => HTMLElement;
    };
}
export interface NotificationManager {
    createNotification: (contents: NotificationContents, options?: NotificationOptions) => Notification;
    dismissNotification: (notificationID: NotificationID) => void;
    dismissAllNotifications: () => void;
    destroy: () => void;
    destroyed: boolean;
    element: HTMLElement;
    activeNotifications: ActiveNotifications;
}
export declare class NotificationManagerDestroyedError extends Error {
    message: string;
}
export declare function getNextNotificationID(activeNotifications: ActiveNotifications): NotificationID;
export declare function shouldAnimate(animationPreference: boolean): boolean;
export declare function createNotificationManager({ container, defaultAnimated, defaultDismissible, defaultExitAnimationTime, defaultAutoDismissTimeout, documentInstance, }?: NotificationManagerOptions): NotificationManager;
